summaryrefslogtreecommitdiffstats
path: root/configdialog/kbfxconfigdlgthemes.ui.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-05 22:07:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-05 22:07:15 +0000
commit421b60af92c83b889f8903c2898f2bd07186fcd8 (patch)
treead873a24c9438baed4942fda795430a4c3dc9a9a /configdialog/kbfxconfigdlgthemes.ui.h
parent39e896bddf25bf34cbf8be814d959181e2c1d1dd (diff)
downloadkbfx-421b60af92c83b889f8903c2898f2bd07186fcd8.tar.gz
kbfx-421b60af92c83b889f8903c2898f2bd07186fcd8.zip
TQt4 port kbfx
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kbfx@1230544 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'configdialog/kbfxconfigdlgthemes.ui.h')
-rw-r--r--configdialog/kbfxconfigdlgthemes.ui.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/configdialog/kbfxconfigdlgthemes.ui.h b/configdialog/kbfxconfigdlgthemes.ui.h
index fe28790..7689989 100644
--- a/configdialog/kbfxconfigdlgthemes.ui.h
+++ b/configdialog/kbfxconfigdlgthemes.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
@@ -17,8 +17,8 @@ void KbfxConfigDlgThemes::init()
KbfxFormReady = FALSE;
img_nopreview = image0;
- connect ( this, SIGNAL ( KbfxThemeDoInstall ( QString & ) ),
- this, SLOT ( KbfxThemeInstall ( QString & ) ) );
+ connect ( this, TQT_SIGNAL ( KbfxThemeDoInstall ( TQString & ) ),
+ this, TQT_SLOT ( KbfxThemeInstall ( TQString & ) ) );
}
/*
@@ -27,14 +27,14 @@ void KbfxConfigDlgThemes::KbfxDudeAnimationButtonToggled(bool)
if(KbfxAnimationButton->state() == 2)
{
KbfxAnimationButton->setText(tr2i18n("Animation is ON"));
- KbfxAnimationButton->setPaletteBackgroundColor(QColor(0,255,0));
+ KbfxAnimationButton->setPaletteBackgroundColor(TQColor(0,255,0));
ConfigInit().m_SpinxDudeBlink = TRUE;
}
if(KbfxAnimationButton->state() == 0)
{
KbfxAnimationButton->setText(tr2i18n("Animation is OFF"));
- KbfxAnimationButton->setPaletteBackgroundColor(QColor(221,223,228));
+ KbfxAnimationButton->setPaletteBackgroundColor(TQColor(221,223,228));
ConfigInit().m_SpinxDudeBlink = FALSE;
}
@@ -44,15 +44,15 @@ void KbfxConfigDlgThemes::KbfxDudeAnimationButtonToggled(bool)
}
*/
-void KbfxConfigDlgThemes::KbfxURLRequesterThemesPathUrlSelected ( const QString &path )
+void KbfxConfigDlgThemes::KbfxURLRequesterThemesPathUrlSelected ( const TQString &path )
{
- QString tmppath = path;
+ TQString tmppath = path;
if ( tmppath.startsWith ( "file://" ) ) tmppath.remove ( "file://" );
if ( !tmppath.endsWith ( "/" ) ) tmppath.append ( "/" );
- QDir d ( tmppath );
- d.setFilter ( QDir::Dirs );
+ TQDir d ( tmppath );
+ d.setFilter ( TQDir::Dirs );
if ( !d.exists() )
{
kdDebug() << "Themes folder does not exist: " << tmppath << endl;
@@ -78,7 +78,7 @@ void KbfxConfigDlgThemes::KbfxURLRequesterThemesPathUrlSelected ( const QString
setKbfxThemePreview();
}
-void KbfxConfigDlgThemes::KbfxThemeSelected ( const QString &name )
+void KbfxConfigDlgThemes::KbfxThemeSelected ( const TQString &name )
{
if (KbfxFormReady)
{
@@ -102,16 +102,16 @@ void KbfxConfigDlgThemes::KbfxThemeSelected ( const QString &name )
void KbfxConfigDlgThemes::setKbfxThemePreview()
{
- QString path = ConfigInit().m_SpinxThemeBasePath + ConfigInit().m_SpinxThemeName + "/preview.png";
+ TQString path = ConfigInit().m_SpinxThemeBasePath + ConfigInit().m_SpinxThemeName + "/preview.png";
- QImage tmp ( path );
+ TQImage tmp ( path );
if ( tmp.isNull() )
{
kdDebug() << "No preview available for theme: "
<< ConfigInit().m_SpinxThemeBasePath + ConfigInit().m_SpinxThemeName
<< endl;
- // QString default_path = locate("data", "kbfx/images/nopreview.png");
+ // TQString default_path = locate("data", "kbfx/images/nopreview.png");
KbfxPixmapPreview->setPixmap ( img_nopreview );
}
else
@@ -132,7 +132,7 @@ void KbfxConfigDlgThemes::ChangeForm()
<< KbfxThemesData().setThemeList ( ConfigInit().m_UserSpinxThemeBasePath ) [ConfigInit().m_SpinxThemeName]
<< endl;
- KbfxThemeList->setSelected ( KbfxThemeList->findItem ( ConfigInit().m_SpinxThemeName ), TRUE );
+ KbfxThemeList->setSelected ( KbfxThemeList->tqfindItem ( ConfigInit().m_SpinxThemeName ), TRUE );
setKbfxThemePreview();
@@ -163,7 +163,7 @@ void KbfxConfigDlgThemes::KbfxDeleteThemeClicked()
{
int messageBoxReturn;
int messageBoxUserResReturn;
- QString KbfxThemeRcDestination = KGlobal::dirs()->saveLocation ( "data", QString ( "kbfx/themerc/" ), TRUE );
+ TQString KbfxThemeRcDestination = KGlobal::dirs()->saveLocation ( "data", TQString ( "kbfx/themerc/" ), TRUE );
KbfxThemeRcDestination.append( ConfigInit().m_SpinxThemeName );
messageBoxReturn = KMessageBox::warningContinueCancel ( 0,
@@ -181,18 +181,18 @@ void KbfxConfigDlgThemes::KbfxDeleteThemeClicked()
if ( messageBoxUserResReturn == KMessageBox::No )
{
- if ( QFile::exists ( KbfxThemeRcDestination + "_fontrc" ) )
+ if ( TQFile::exists ( KbfxThemeRcDestination + "_fontrc" ) )
{
- QFile::remove ( KbfxThemeRcDestination + "_fontrc" );
+ TQFile::remove ( KbfxThemeRcDestination + "_fontrc" );
kdDebug() << "Deleting user's fontrc file: "
<< KbfxThemeRcDestination + "_fontrc"
<< endl;
}
- if ( QFile::exists ( KbfxThemeRcDestination + "_layoutrc" ) )
+ if ( TQFile::exists ( KbfxThemeRcDestination + "_layoutrc" ) )
{
- QFile::remove ( KbfxThemeRcDestination + "_layoutrc" );
- kdDebug() << "Deleting user's layoutrc file: "
+ TQFile::remove ( KbfxThemeRcDestination + "_layoutrc" );
+ kdDebug() << "Deleting user's tqlayoutrc file: "
<< KbfxThemeRcDestination + "_layoutrc"
<< endl;
}
@@ -219,7 +219,7 @@ void KbfxConfigDlgThemes::KbfxDeleteThemeClicked()
void KbfxConfigDlgThemes::KbfxInstallThemeClicked()
{
- KFileDialog KbfxInstallDialog ( QString::null,
+ KFileDialog KbfxInstallDialog ( TQString(),
"*.tar *.tar.bz2 *.tar.gz *.kbfxtheme|" + tr2i18n ( "KBFX theme packages (*.tar, *.tar.bz2, *.tar.gz, *.kbfxtheme)" ),
0,
0,
@@ -234,7 +234,7 @@ void KbfxConfigDlgThemes::KbfxInstallThemeClicked()
emit KbfxThemeDoInstall ( KbfxInstallDialogURL );
}
-void KbfxConfigDlgThemes::KbfxThemeInstall ( QString &installUrl )
+void KbfxConfigDlgThemes::KbfxThemeInstall ( TQString &installUrl )
{
KTar KbfxThemeArchive ( installUrl );
@@ -247,8 +247,8 @@ void KbfxConfigDlgThemes::KbfxThemeInstall ( QString &installUrl )
return;
}
- const QString KbfxThemeDestination = KGlobal::dirs()->saveLocation ( "data",
- QString ( "kbfx/skins/" ),
+ const TQString KbfxThemeDestination = KGlobal::dirs()->saveLocation ( "data",
+ TQString ( "kbfx/skins/" ),
TRUE );
kdDebug() << "Copying theme: " << KbfxThemeDestination << endl;
@@ -261,7 +261,7 @@ void KbfxConfigDlgThemes::KbfxThemeInstall ( QString &installUrl )
void KbfxConfigDlgThemes::KbfxSelectDudeImageClicked()
{
- KFileDialog KbfxDudeImageDialog ( QString::null,
+ KFileDialog KbfxDudeImageDialog ( TQString(),
"image/jpeg image/png image/x-xpm image/gif ",
0,
0,
@@ -274,7 +274,7 @@ void KbfxConfigDlgThemes::KbfxSelectDudeImageClicked()
ConfigInit().m_SpinxDudeImage = KbfxDudeImageDialog.selectedURL().path();
- QImage tmp ( ConfigInit().m_SpinxDudeImage );
+ TQImage tmp ( ConfigInit().m_SpinxDudeImage );
if ( tmp.isNull() )
{
KMessageBox::error ( 0,
@@ -295,8 +295,8 @@ void KbfxConfigDlgThemes::KbfxSelectDudeImageClicked()
void KbfxConfigDlgThemes::KbfxDeleteDudeImageClicked()
{
- QString tmp_dude = ConfigInit().m_SpinxThemeBasePath + ConfigInit().m_SpinxThemeName + "/menu_top_image_person.png";
- QFile tmp ( tmp_dude );
+ TQString tmp_dude = ConfigInit().m_SpinxThemeBasePath + ConfigInit().m_SpinxThemeName + "/menu_top_image_person.png";
+ TQFile tmp ( tmp_dude );
if ( tmp.exists() )
{
ConfigInit().m_SpinxDudeImage = tmp_dude;
@@ -312,10 +312,10 @@ void KbfxConfigDlgThemes::KbfxDeleteDudeImageClicked()
void KbfxConfigDlgThemes::KbfxThemeInfoClicked()
{
- QPixmap _logo = QPixmap (ConfigInit ().m_SpinxThemeBasePath + ConfigInit ().m_SpinxThemeName + "/logo.png");
+ TQPixmap _logo = TQPixmap (ConfigInit ().m_SpinxThemeBasePath + ConfigInit ().m_SpinxThemeName + "/logo.png");
ConfigInit().readThemeInfo ( ConfigInit().m_SpinxThemeBasePath, ConfigInit().m_SpinxThemeName );
- _info_box = new KbfxThemeInfo (this,"infodlg",Qt::WType_Modal);
+ _info_box = new KbfxThemeInfo (this,"infodlg",TQt::WType_Modal);
if ( !_logo.isNull() )
{
@@ -2,7 +2,7 @@
**
** If you want to add, delete, or rename functions or slots, use
-** Qt Designer to update this file, preserving your code.
+** TQt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.